@@ -10,9 +10,8 @@
 
 import re
 
-from pint.compat import babel_parse
-
 from .babel_names import _babel_systems
+from .compat import babel_parse
 from .definitions import Definition, UnitDefinition
 from .errors import DefinitionSyntaxError, RedefinitionError
 from .util import (
@@ -174,7 +173,7 @@ class Group(SharedRegistryObject):
         self.invalidate_members()
 
     @classmethod
-    def from_lines(cls, lines, define_func):
+    def from_lines(cls, lines, define_func, non_int_type=float):
         """Return a Group object parsing an iterable of lines.
 
         Parameters
@@ -208,7 +207,7 @@ class Group(SharedRegistryObject):
         for lineno, line in lines:
             if "=" in line:
                 # Is a definition
-                definition = Definition.from_string(line)
+                definition = Definition.from_string(line, non_int_type=non_int_type)
                 if not isinstance(definition, UnitDefinition):
                     raise DefinitionSyntaxError(
                         "Only UnitDefinition are valid inside _used_groups, not "
@@ -357,7 +356,7 @@ class System(SharedRegistryObject):
         return self.name
 
     @classmethod
-    def from_lines(cls, lines, get_root_func):
+    def from_lines(cls, lines, get_root_func, non_int_type=float):
         lines = SourceIterator(lines)
 
         lineno, header = next(lines)
@@ -399,7 +398,9 @@ class System(SharedRegistryObject):
                     )
 
                 # Here we find new_unit expanded in terms of root_units
-                new_unit_expanded = to_units_container(get_root_func(new_unit)[1])
+                new_unit_expanded = to_units_container(
+                    get_root_func(new_unit)[1], cls._REGISTRY
+                )
 
                 # We require that the old unit is present in the new_unit expanded
                 if old_unit not in new_unit_expanded:
@@ -408,7 +409,7 @@ class System(SharedRegistryObject):
                 # Here we invert the equation, in other words
                 # we write old units in terms new unit and expansion
                 new_unit_dict = {
-                    new_unit: -1.0 / value
+                    new_unit: -1 / value
                     for new_unit, value in new_unit_expanded.items()
                     if new_unit != old_unit
                 }
@@ -430,7 +431,7 @@ class System(SharedRegistryObject):
 
                 old_unit, value = dict(old_unit_dict).popitem()
 
-                base_unit_names[old_unit] = {new_unit: 1.0 / value}
+                base_unit_names[old_unit] = {new_unit: 1 / value}
 
         system = cls(name)
 
