@@ -5,7 +5,7 @@ import unittest
 
 import pytest
 
-from pint import Context, DimensionalityError, UnitRegistry
+from pint import Context, DimensionalityError, UnitRegistry, get_application_registry
 from pint.compat import np
 from pint.testsuite import QuantityTestCase, helpers
 from pint.unit import UnitsContainer
@@ -325,16 +325,6 @@ class TestIssues(QuantityTestCase):
         self.assertQuantityAlmostEqual(x + y, 5.1 * ureg.meter)
         self.assertQuantityAlmostEqual(z, 5.1 * ureg.meter)
 
-    @helpers.requires_numpy_previous_than("1.10")
-    def test_issue94(self):
-        v1 = np.array([5, 5]) * ureg.meter
-        v2 = 0.1 * ureg.meter
-        v3 = np.array([5, 5]) * ureg.meter
-        v3 += v2
-
-        np.testing.assert_array_equal((v1 + v2).magnitude, np.array([5.1, 5.1]))
-        np.testing.assert_array_equal(v3.magnitude, np.array([5, 5]))
-
     def test_issue104(self):
 
         x = [ureg("1 meter"), ureg("1 meter"), ureg("1 meter")]
@@ -367,40 +357,6 @@ class TestIssues(QuantityTestCase):
                 func("METER")
             self.assertEqual(val, func("METER", False))
 
-    def test_issue121(self):
-        z, v = 0, 2.0
-        self.assertEqual(z + v * ureg.meter, v * ureg.meter)
-        self.assertEqual(z - v * ureg.meter, -v * ureg.meter)
-        self.assertEqual(v * ureg.meter + z, v * ureg.meter)
-        self.assertEqual(v * ureg.meter - z, v * ureg.meter)
-
-        self.assertEqual(sum([v * ureg.meter, v * ureg.meter]), 2 * v * ureg.meter)
-
-    @helpers.requires_numpy18()
-    def test_issue121b(self):
-        sh = (2, 1)
-
-        z, v = 0, 2.0
-        self.assertEqual(z + v * ureg.meter, v * ureg.meter)
-        self.assertEqual(z - v * ureg.meter, -v * ureg.meter)
-        self.assertEqual(v * ureg.meter + z, v * ureg.meter)
-        self.assertEqual(v * ureg.meter - z, v * ureg.meter)
-
-        self.assertEqual(sum([v * ureg.meter, v * ureg.meter]), 2 * v * ureg.meter)
-
-        z, v = np.zeros(sh), 2.0 * np.ones(sh)
-        self.assertQuantityEqual(z + v * ureg.meter, v * ureg.meter)
-        self.assertQuantityEqual(z - v * ureg.meter, -v * ureg.meter)
-        self.assertQuantityEqual(v * ureg.meter + z, v * ureg.meter)
-        self.assertQuantityEqual(v * ureg.meter - z, v * ureg.meter)
-
-        z, v = np.zeros((3, 1)), 2.0 * np.ones(sh)
-        for x, y in ((z, v), (z, v * ureg.meter), (v * ureg.meter, z)):
-            with self.assertRaises(ValueError):
-                x + y
-            with self.assertRaises(ValueError):
-                x - y
-
     @helpers.requires_numpy()
     def test_issue127(self):
         q = [1.0, 2.0, 3.0, 4.0] * self.ureg.meter
@@ -503,6 +459,19 @@ class TestIssues(QuantityTestCase):
         p = (q ** q).m
         np.testing.assert_array_equal(p, a ** a)
 
+    def test_issue507(self):
+        # leading underscore in unit works with numbers
+        ureg.define("_100km = 100 * kilometer")
+        battery_ec = 16 * ureg.kWh / ureg._100km  # noqa: F841
+        # ... but not with text
+        ureg.define("_home = 4700 * kWh / year")
+        with self.assertRaises(AttributeError):
+            home_elec_power = 1 * ureg._home  # noqa: F841
+        # ... or with *only* underscores
+        ureg.define("_ = 45 * km")
+        with self.assertRaises(AttributeError):
+            one_blank = 1 * ureg._  # noqa: F841
+
     def test_issue523(self):
         src, dst = UnitsContainer({"meter": 1}), UnitsContainer({"degF": 1})
         value = 10.0
@@ -551,7 +520,7 @@ class TestIssues(QuantityTestCase):
 
         lunar_module_height = Q_(10, "m")
         t1 = calculate_time_to_fall(lunar_module_height)
-        print(t1)
+        # print(t1)
         self.assertAlmostEqual(t1, Q_(1.4285714285714286, "s"))
 
         moon_gravity = Q_(1.625, "m/s^2")
@@ -611,7 +580,7 @@ class TestIssues(QuantityTestCase):
 
         @ureg.check("[length]", "[length]/[time]^2")
         def pendulum_period(length, G=Q_(1, "standard_gravity")):
-            print(length)
+            # print(length)
             return (2 * math.pi * (length / G) ** 0.5).to("s")
 
         length = Q_(1, ureg.m)
@@ -697,10 +666,126 @@ class TestIssues(QuantityTestCase):
         with self.assertRaises(DimensionalityError):
             q.to("joule")
 
+    def test_issue960(self):
+        q = (1 * ureg.nanometer).to_compact("micrometer")
+        assert q.units == ureg.nanometer
+        assert q.magnitude == 1
 
-try:
+    def test_issue1032(self):
+        class MultiplicativeDictionary(dict):
+            def __rmul__(self, other):
+                return self.__class__(
+                    {key: value * other for key, value in self.items()}
+                )
+
+        q = 3 * ureg.s
+        d = MultiplicativeDictionary({4: 5, 6: 7})
+        assert q * d == MultiplicativeDictionary({4: 15 * ureg.s, 6: 21 * ureg.s})
+        with self.assertRaises(TypeError):
+            d * q
+
+    @helpers.requires_numpy()
+    def test_issue973(self):
+        """Verify that an empty array Quantity can be created through multiplication."""
+        q0 = np.array([]) * ureg.m  # by Unit
+        q1 = np.array([]) * ureg("m")  # by Quantity
+        assert isinstance(q0, ureg.Quantity)
+        assert isinstance(q1, ureg.Quantity)
+        assert len(q0) == len(q1) == 0
+
+    def test_issue1058(self):
+        """ verify that auto-reducing quantities with three or more units
+        of same base type succeeds """
+        q = 1 * ureg.mg / ureg.g / ureg.kg
+        q.ito_reduced_units()
+        self.assertIsInstance(q, ureg.Quantity)
+
+    def test_issue1062_issue1097(self):
+        # Must not be used by any other tests
+        assert "nanometer" not in ureg._units
+        for i in range(5):
+            ctx = Context.from_lines(["@context _", "cal = 4 J"])
+            with ureg.context("sp", ctx):
+                q = ureg.Quantity(1, "nm")
+                q.to("J")
+
+    def test_issue1086(self):
+        # units with prefixes should correctly test as 'in' the registry
+        assert "bits" in ureg
+        assert "gigabits" in ureg
+        assert "meters" in ureg
+        assert "kilometers" in ureg
+        # unknown or incorrect units should test as 'not in' the registry
+        assert "magicbits" not in ureg
+        assert "unknownmeters" not in ureg
+        assert "gigatrees" not in ureg
+
+    def test_issue1112(self):
+        ureg = UnitRegistry(
+            """
+            m = [length]
+            g = [mass]
+            s = [time]
+
+            ft = 0.305 m
+            lb = 454 g
+
+            @context c1
+                [time]->[length] : value * 10 m/s
+            @end
+            @context c2
+                ft = 0.3 m
+            @end
+            @context c3
+                lb = 500 g
+            @end
+            """.splitlines()
+        )
+        ureg.enable_contexts("c1")
+        ureg.enable_contexts("c2")
+        ureg.enable_contexts("c3")
+
+    @helpers.requires_numpy()
+    def test_issue1144_1102(self):
+        # Performing operations shouldn't modify the original objects
+        # Issue 1144
+        ddc = "delta_degree_Celsius"
+        q1 = ureg.Quantity([-287.78, -32.24, -1.94], ddc)
+        q2 = ureg.Quantity(70.0, "degree_Fahrenheit")
+        q1 - q2
+        assert all(q1 == ureg.Quantity([-287.78, -32.24, -1.94], ddc))
+        assert q2 == ureg.Quantity(70.0, "degree_Fahrenheit")
+        q2 - q1
+        assert all(q1 == ureg.Quantity([-287.78, -32.24, -1.94], ddc))
+        assert q2 == ureg.Quantity(70.0, "degree_Fahrenheit")
+        # Issue 1102
+        val = [30.0, 45.0, 60.0] * ureg.degree
+        val == 1
+        1 == val
+        assert all(val == ureg.Quantity([30.0, 45.0, 60.0], "degree"))
+        # Test for another bug identified by searching on "_convert_magnitude"
+        q2 = ureg.Quantity(3, "degree_Kelvin")
+        q1 - q2
+        assert all(q1 == ureg.Quantity([-287.78, -32.24, -1.94], ddc))
+
+    @helpers.requires_numpy()
+    def test_issue_1136(self):
+        assert (2 ** ureg.Quantity([2, 3], "") == 2 ** np.array([2, 3])).all()
+
+        with pytest.raises(DimensionalityError):
+            2 ** ureg.Quantity([2, 3], "m")
+
+    def test_issue1175(self):
+        import pickle
+
+        foo1 = get_application_registry().Quantity(1, "s")
+        foo2 = pickle.loads(pickle.dumps(foo1))
+        self.assertIsInstance(foo1, foo2.__class__)
+        self.assertIsInstance(foo2, foo1.__class__)
+
+
+if np is not None:
 
-    @pytest.mark.skipif(np is None, reason="NumPy is not available")
     @pytest.mark.parametrize(
         "callable",
         [
@@ -732,17 +817,3 @@ try:
         type_before = type(q._magnitude)
         callable(q)
         assert isinstance(q._magnitude, type_before)
-
-    @pytest.mark.skipif(np is None, reason="NumPy is not available")
-    def test_issue973():
-        """Verify that an empty array Quantity can be created through multiplication."""
-        q0 = np.array([]) * ureg.m  # by Unit
-        q1 = np.array([]) * ureg("m")  # by Quantity
-        assert isinstance(q0, ureg.Quantity)
-        assert isinstance(q1, ureg.Quantity)
-        assert len(q0) == len(q1) == 0
-
-
-except AttributeError:
-    # Calling attributes on np will fail if NumPy is not available
-    pass
